yakumo.nova.v2.network.Resource

Package yakumo :: Package nova :: Package v2 :: Module network :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for networks in Compute API v2

Instance Methods | [hide private]
None |
associate(self) Associate a network | source code
None |
disassociate(self) Disassociate a network | source code
None |
associate_host(self, host=None) Associate a host to a network | source code
None |
disassociate_host(self, host=None) Disassociate a host to a network | source code
None |
disassociate_project(self, project=None) Disassociate a host to a network | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### associate_host(self, host=None) | source code
Associate a host to a network Parameters: `host` (str) - UUID of a host (required) Returns: None

### disassociate_host(self, host=None) | source code
Disassociate a host to a network Parameters: `host` (str) - UUID of a host (required) Returns: None

### disassociate_project(self, project=None) | source code
Disassociate a host to a network Parameters: `project` (yakumo.project.Resource) - Project Returns: None